@@ -1,18 +1,25 @@
 package Mojolicious::Plugin::Notifications;
 use Mojo::Base 'Mojolicious::Plugin';
+use Mojo::Collection qw/c/;
 use Mojolicious::Plugin::Notifications::Assets;
 use Mojo::Util qw/camelize/;
 use Scalar::Util qw/blessed/;
 
 our $TYPE_RE = qr/^[-a-zA-Z_]+$/;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
-# Todo: Maybe revert to tx-handler and use session instead of flash!
+# TODO:
+#   Maybe revert to tx-handler and use session instead of flash!
 
-# Todo: Support Multiple Times Loading
-# Explain camelize and :: behaviour for engine names
-# Subroutines for Engines should be given directly
+# TODO:
+#   Support Multiple Times Loading
+# TODO:
+#   Explain camelize and :: behaviour for engine names
+# TODO:
+#   Subroutines for Engines should be given directly
+# TODO:
+#   Engines may use hooks in addition
 
 # Register plugin
 sub register {
@@ -48,13 +55,6 @@ sub register {
 
   # Set assets
   foreach (values %engine) {
-
-    # The check is a deprecation option!
-    if (!$_->can('styles') || !$_->can('scripts')) {
-      $app->log->warn(blessed($_) . ' is not based on ' .
-        __PACKAGE__ . '::Engine, which is DEPRECATED!');
-    };
-
     $asset->styles($_->styles)   if $_->can('styles');
     $asset->scripts($_->scripts) if $_->can('scripts');
   };
@@ -70,16 +70,16 @@ sub register {
       # Ignore debug messages in production
       return if $type !~ $TYPE_RE || (!$debug && $type eq 'debug');
 
-      my $array;
+      my $notes;
 
       # Notifications already set
-      if ($array = $c->stash('notify.array')) {
-        push (@$array, [$type => @msg]);
+      if ($notes = $c->stash('notify.array')) {
+        push @$notes, [$type => @msg];
       }
 
-      # New notifications
+      # New notifications as a Mojo::Collection
       else {
-        $c->stash('notify.array' => [[$type => @msg]]);
+        $c->stash('notify.array' => c([$type => @msg]));
       };
     }
   );
@@ -95,7 +95,8 @@ sub register {
       my $e_type = lc shift;
       my @param = @_;
 
-      my @notify_array;
+      # Get stash notifications
+      my $notes = ($c->stash->{'notify.array'} //= c());
 
       # Get flash notifications
       my $flash = $c->flash('n!.a');
@@ -103,19 +104,19 @@ sub register {
       if ($flash && ref $flash eq 'ARRAY') {
 
         # Ensure that no harmful types are injected
-        push @notify_array, grep { $_->[0] =~ $TYPE_RE } @$flash;
-
-        # Use "n!.a" instead of notify.array as this goes into the cookie
-        # $c->flash('n!.a' => undef);
+        unshift @$notes, grep { $_->[0] =~ $TYPE_RE } @$flash;
       };
 
-      # Get stash notifications
-      if ($c->stash('notify.array')) {
-        push @notify_array, @{ delete $c->stash->{'notify.array'} };
-      };
+      # Emit hook for further flexibility
+      $app->plugins->emit_hook(
+        before_notifications => $c, $notes
+      );
+
+      # Delete from stash
+      delete $c->stash->{'notify.array'};
 
       # Nothing to do
-      return '' unless @notify_array || @_;
+      return '' unless $notes->size || @_;
 
       # Forward messages to notification center
       if (exists $engine{$e_type}) {
@@ -125,7 +126,7 @@ sub register {
           $rule{lc(substr(pop @param, 1))} = 1;
         };
 
-        return $engine{$e_type}->notifications($c, \@notify_array, \%rule, @param);
+        return $engine{$e_type}->notifications($c, $notes, \%rule, @param);
       }
       else {
         $c->app->log->error(qq{Unknown notification engine "$e_type"});
@@ -311,9 +312,25 @@ L<Humane.js|Mojolicious::Plugin::Notifications::Humane>, and
 L<Alertify.js|Mojolicious::Plugin::Notifications::Alertify>,
 
 
+=head1 HOOKS
+
+  app->hook(
+    before_notifications => sub {
+      my ($c, $notes) = @_;
+      $c->app->log('Served ' . $notes->size . ' notifications to ' . $c->stash('user'));
+    });
+
+This hook is emitted before any notifications are rendered.
+The hook passes the current controller object and a L<Mojo::Collection>
+object including all notes.
+The hook is emitted no matter if notifications are pending.
+
+B<This hook is EXPERIMENTAL!>
+
+
 =head1 SEE ALSO
 
-If you want to use Humane.js without L<Mojolicious::Plugin::Notifications>,
+If you want to use C<Humane.js> without L<Mojolicious::Plugin::Notifications>,
 you should have a look at L<Mojolicious::Plugin::Humane>,
 which was the original inspiration for this plugin.
 
@@ -329,7 +346,7 @@ compatible.
 =head1 HINTS
 
 As flash information is stored in the session, notifications may be lost
-in case the session expires using C<$c->session(expires => 1)>.
+in case the session expires using C<session(expires => 1)>.
 
 
 =head1 AVAILABILITY
@@ -339,7 +356,7 @@ in case the session expires using C<$c->session(expires => 1)>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2017, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2014-2018, L<Nils Diewald|https://nils-diewald.de/>.
 
 Part of the code was written at the
 L<Mojoconf 2014|http://www.mojoconf.org/mojo2014/> hackathon.
